==> node-1.1.6.tgz: package/esm/client.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { getSdk, } from './graph/generated/operations';
import ErrorStackParser from 'error-stack-parser';
import { GraphQLClient } from 'graphql-request';
import { ErrorContext } from './errorContext';
var Highlight = /** @class */ (function () {
    function Highlight(options) {
        var _this = this;
        this.FLUSH_TIMEOUT = 10;
        this.BACKEND_SETUP_TIMEOUT = 15 * 60 * 1000;
        this.errors = [];
        this.metrics = [];
        this.lastBackendSetupEvent = 0;
        this._backendUrl = options.backendUrl || 'https://pub.highlight.run';
        var client = new GraphQLClient(this._backendUrl, {
            headers: {},
        });
        this._graphqlSdk = getSdk(client);
        this._intervalFunction = setInterval(function () { return _this.flush(); }, this.FLUSH_TIMEOUT * 1000);
        if (!options.disableErrorSourceContext) {
            this._errorContext = new ErrorContext({
                sourceContextCacheSizeMB: options.errorSourceContextCacheSizeMB,
            });
        }
    }
    Highlight.prototype.recordMetric = function (secureSessionId, name, value, requestId) {
        this.metrics.push({
            session_secure_id: secureSessionId,
            group: requestId,
            name: name,
            value: value,
            category: 'BACKEND',
            timestamp: new Date().toISOString(),
        });
    };
    Highlight.prototype.consumeCustomError = function (error, secureSessionId, requestId) {
        var _this = this;
        var res = [];
        try {
            res = ErrorStackParser.parse(error);
            res = res.map(function (frame) {
                var _a;
                try {
                    if (frame.fileName !== undefined &&
                        frame.lineNumber !== undefined) {
                        var context = (_a = _this._errorContext) === null || _a === void 0 ? void 0 : _a.getStackFrameContext(frame.fileName, frame.lineNumber);
                        return __assign(__assign({}, frame), context);
                    }
                }
                catch (_b) { }
                // If the frame doesn't have filename or line number defined, or
                // an error was thrown while getting the stack frame context, return
                // the original frame.
                return frame;
            });
        }
        catch (_a) { }
        this.errors.push({
            event: error.message
                ? "".concat(error.name, ": ").concat(error.message)
                : "".concat(error.name),
            request_id: requestId,
            session_secure_id: secureSessionId,
            source: '',
            stackTrace: JSON.stringify(res),
            timestamp: new Date().toISOString(),
            type: 'BACKEND',
            url: '',
        });
    };
    Highlight.prototype.consumeCustomEvent = function (secureSessionId) {
        var _this = this;
        var sendBackendSetup = Date.now() - this.lastBackendSetupEvent >
            this.BACKEND_SETUP_TIMEOUT;
        if (sendBackendSetup) {
            this._graphqlSdk
                .MarkBackendSetup({
                session_secure_id: secureSessionId,
            })
                .then(function () {
                _this.lastBackendSetupEvent = Date.now();
            })
                .catch(function (e) {
                console.log('highlight-node error: ', e);
            });
        }
    };
    Highlight.prototype.flushErrors = function () {
        if (this.errors.length === 0) {
            return;
        }
        var variables = {
            errors: this.errors,
        };
        this.errors = [];
        this._graphqlSdk
            .PushBackendPayload(variables)
            .then(function () { })
            .catch(function (e) {
            console.log('highlight-node pushErrors error: ', e);
        });
    };
    Highlight.prototype.flushMetrics = function () {
        if (this.metrics.length === 0) {
            return;
        }
        var variables = {
            metrics: this.metrics,
        };
        this.metrics = [];
        this._graphqlSdk
            .PushMetrics(variables)
            .then(function () { })
            .catch(function (e) {
            console.log('highlight-node pushMetrics error: ', e);
        });
    };
    Highlight.prototype.flush = function () {
        this.flushErrors();
        this.flushMetrics();
    };
    return Highlight;
}());
export { Highlight };

==> node-1.1.7.tgz: package/esm/client.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { getSdk, } from './graph/generated/operations';
import ErrorStackParser from 'error-stack-parser';
import { GraphQLClient } from 'graphql-request';
import { ErrorContext } from './errorContext';
var Highlight = /** @class */ (function () {
    function Highlight(options) {
        var _this = this;
        this.FLUSH_TIMEOUT = 10;
        this.BACKEND_SETUP_TIMEOUT = 15 * 60 * 1000;
        this.errors = [];
        this.metrics = [];
        this.lastBackendSetupEvent = 0;
        this._backendUrl = options.backendUrl || 'https://pub.highlight.run';
        var client = new GraphQLClient(this._backendUrl, {
            headers: {},
        });
        this._graphqlSdk = getSdk(client);
        this._intervalFunction = setInterval(function () { return _this.flush(); }, this.FLUSH_TIMEOUT * 1000);
        if (!options.disableErrorSourceContext) {
            this._errorContext = new ErrorContext({
                sourceContextCacheSizeMB: options.errorSourceContextCacheSizeMB,
            });
        }
    }
    Highlight.prototype.recordMetric = function (secureSessionId, name, value, requestId) {
        this.metrics.push({
            session_secure_id: secureSessionId,
            group: requestId,
            name: name,
            value: value,
            category: 'BACKEND',
            timestamp: new Date().toISOString(),
        });
    };
    Highlight.prototype.consumeCustomError = function (error, secureSessionId, requestId) {
        var _this = this;
        var res = [];
        try {
            res = ErrorStackParser.parse(error);
            res = res.map(function (frame) {
                var _a;
                try {
                    if (frame.fileName !== undefined &&
                        frame.lineNumber !== undefined) {
                        var context = (_a = _this._errorContext) === null || _a === void 0 ? void 0 : _a.getStackFrameContext(frame.fileName, frame.lineNumber);
                        return __assign(__assign({}, frame), context);
                    }
                }
                catch (_b) { }
                // If the frame doesn't have filename or line number defined, or
                // an error was thrown while getting the stack frame context, return
                // the original frame.
                return frame;
            });
        }
        catch (_a) { }
        this.errors.push({
            event: error.message
                ? "".concat(error.name, ": ").concat(error.message)
                : "".concat(error.name),
            request_id: requestId,
            session_secure_id: secureSessionId,
            source: '',
            stackTrace: JSON.stringify(res),
            timestamp: new Date().toISOString(),
            type: 'BACKEND',
            url: '',
        });
    };
    Highlight.prototype.consumeCustomEvent = function (secureSessionId) {
        var _this = this;
        var sendBackendSetup = Date.now() - this.lastBackendSetupEvent > this.BACKEND_SETUP_TIMEOUT;
        if (sendBackendSetup) {
            this._graphqlSdk
                .MarkBackendSetup({
                session_secure_id: secureSessionId,
            })
                .then(function () {
                _this.lastBackendSetupEvent = Date.now();
            })
                .catch(function (e) {
                console.log('highlight-node error: ', e);
            });
        }
    };
    Highlight.prototype.flushErrors = function () {
        if (this.errors.length === 0) {
            return;
        }
        var variables = {
            errors: this.errors,
        };
        this.errors = [];
        this._graphqlSdk
            .PushBackendPayload(variables)
            .then(function () { })
            .catch(function (e) {
            console.log('highlight-node pushErrors error: ', e);
        });
    };
    Highlight.prototype.flushMetrics = function () {
        if (this.metrics.length === 0) {
            return;
        }
        var variables = {
            metrics: this.metrics,
        };
        this.metrics = [];
        this._graphqlSdk
            .PushMetrics(variables)
            .then(function () { })
            .catch(function (e) {
            console.log('highlight-node pushMetrics error: ', e);
        });
    };
    Highlight.prototype.flush = function () {
        this.flushErrors();
        this.flushMetrics();
    };
    return Highlight;
}());
export { Highlight };
